/**
 * Handle URL requests for the Vite dev server.
 */
import rehypeParse from "rehype-parse";
import rehypeStringify from "rehype-stringify";
import { unified } from "unified";
import { routerVirtualModuleId } from "./pluginRouter.js";
const clientEntry = "/@bspeice/vite-plugin-blog/main.js";
const clientHtml = `
<!DOCTYPE html>
<html>
<body>
  <div id="root"></div>
  <script src="${clientEntry}" type="module"></script>
</body>
</html>`;
export default function pluginDev(moduleMap, rehypePlugins) {
    const processor = unified()
        .use(rehypeParse)
        .use(rehypePlugins)
        .use(rehypeStringify);
    let thisServer;
    const serve = async (req, res) => {
        const html = String(await processor.process(clientHtml));
        res.writeHead(req.originalUrl in moduleMap ? 200 : 404, {
            "Content-Type": "text/html",
        });
        res.write(await thisServer.transformIndexHtml(req.originalUrl, html));
        res.end();
    };
    return {
        name: "vite-plugin-blog:dev",
        apply: "serve",
        config() {
            return {
                optimizeDeps: {
                    exclude: [routerVirtualModuleId],
                },
            };
        },
        configureServer(server) {
            // Register as a hook so Vite has an opportunity to serve everything first.
            // As a result, if we don't know about it, can treat as 404.
            thisServer = server;
            return () => {
                server.middlewares.use(serve);
            };
        },
        resolveId(id) {
            if (id === clientEntry) {
                return id;
            }
        },
        load(id) {
            if (id === clientEntry) {
                return `import "@bspeice/vite-plugin-blog/dist/entryClientDev.js";`;
            }
        },
    };
}
