/**
 * The basic "trick" of this plugin is to let Vite/Rollup translate modules
 * to something we can import, then render those modules in the dev server
 * or to static markup.
 *
 * However, there's a complication: we don't have a consistent way to import
 * those modules in both the client (browser) and server (nodejs).
 *
 * To deal with that, this plugin synthesizes a
 * [virtual module](https://vitejs.dev/guide/api-plugin.html#virtual-modules-convention)
 * that imports the provided modules. Vite/Rollup will replace the provided module paths
 * with the relevant output paths, and then we have easy access to everything we need.
 */
import { Plugin } from "vite";
export declare const routerVirtualModuleId = "virtual:vite-plugin-blog:router";
export declare const routerResolvedVirtualModuleId: string;
export default function pluginRouter(moduleMap: Record<string, string>): Plugin;
